==> fileslog-1.0.0.tar.gz: fileslog/src/Controller/FilesLogController.php <==
<?php

namespace Drupal\fileslog\Controller;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Http\RequestStack;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\Core\Pager\PagerManagerInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\fileslog\Form\FileslogFilterForm;
use Drupal\fileslog\Logger\FilesLog;
use Drupal\user\Entity\User;
use Drupal\user\UserInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Renders the fileslog routes.
 */
class FilesLogController extends ControllerBase {

  /**
   * Define defaults.
   */
  protected const MAX_MESSAGE_LENGTH = 64;
  protected const ITEMS_PER_PAGE = 25;

  /**
   * The filesystem service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected FileSystemInterface $fileSystem;

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request|null
   */
  protected ?Request $request;

  /**
   * The pager manager.
   *
   * @var \Drupal\Core\Pager\PagerManagerInterface
   */
  protected PagerManagerInterface $pagerManager;

  /**
   * Constructs the controller.
   *
   * @param \Drupal\Core\File\FileSystemInterface $filesystem
   *   The filesystem service.
   * @param \Drupal\Core\Http\RequestStack $request_stack
   *   The request stack.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder.
   * @param \Drupal\Core\Pager\PagerManagerInterface $pager_manager
   *   The pager manager.
   */
  public function __construct(
    FileSystemInterface $filesystem,
    RequestStack $request_stack,
    FormBuilderInterface $form_builder,
    PagerManagerInterface $pager_manager
  ) {
    $this->fileSystem = $filesystem;
    $this->request = $request_stack->getCurrentRequest();
    $this->formBuilder = $form_builder;
    $this->pagerManager = $pager_manager;
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('file_system'),
      $container->get('request_stack'),
      $container->get('form_builder'),
      $container->get('pager.manager')
    );
  }

  /**
   * View page for each log.
   *
   * @param string $filename
   *   The log's filename.
   *
   * @return array
   *   The render array.
   *
   * @throws \Drupal\Core\Entity\EntityMalformedException
   */
  public function view(string $filename): array {
    $uri = FilesLog::DIRECTORY . '/' . $filename . '.json';
    $file_contents = file_get_contents($this->fileSystem->realpath($uri));
    $log = Json::decode($file_contents);
    $user = User::load($log['uid']);

    return [
      '#type' => 'inline_template',
      '#template' => '<span class="fileslog--back-to-overview"><a href="javascript:history.back();" class="button">{{ "Back to overview"|t }}</a></span>
<table>
<tr><td><strong>Level</strong>:</td><td>{{ severity }}</td></tr>
<tr><td><strong>User</strong>:</td><td>{{ user|raw }}</td></tr>
<tr><td><strong>Date</strong>:</td><td>{{ date }}</td></tr>
<tr><td colspan="2"><strong>Message</strong>:<pre>{{ message }}</pre></td></tr>
</table>',
      '#context' => [
        'severity' => $this->getLogLevelLabel($log['severity']),
        'user' => $user instanceof UserInterface && $user->id() != '0'
          ? '<a href="' . $user->toUrl()->toString() . '">' . $user->label() . '</a>'
          : $this->t('Anonymous (not verified)'),
        'date' => DrupalDateTime::createFromTimestamp($log['timestamp'] ?? 0)->format('Y-m-d H:i:s'),
        'message' => $log['message'],
      ],
    ];
  }

  /**
   * Overview of logs.
   *
   * @return array
   *   The render array.
   *
   * @throws \Drupal\Core\Entity\EntityMalformedException
   */
  public function overview(): array {
    $table = [
      '#type' => 'table',
      '#header' => [
        $this->t('Severity'),
        $this->t('Category'),
        $this->t('Date'),
        $this->t('Message'),
        $this->t('User'),
      ],
      '#rows' => [],
    ];

    // Retrieve all .json files from the directory.
    $files = $this->fileSystem->scanDirectory(FilesLog::DIRECTORY, '/(.?)\.json/', ['recurse' => FALSE]);
    // Sort the log files in reverse, so the latest show up first.
    krsort($files);
    $filters = $this->request->getSession()->get(FileslogFilterForm::SESSION_VALUE_NAME, []);
    $levels = $filters['severity'] ?? [];
    if (count($levels) > 0) {
      $files = array_filter($files, function ($file) use ($levels) {
        foreach ($levels as $filter_level) {
          [$timestamp, $log_level] = explode('-', $file->name);
          if ($log_level == $filter_level) {
            return TRUE;
          }
        }
        return FALSE;
      });
    }

    $page = $this->pagerManager->findPage();
    $offset = $page * self::ITEMS_PER_PAGE;
    $total = count($files);

    $files = array_slice($files, $offset, self::ITEMS_PER_PAGE);
    foreach ($files as $uri => $file) {
      $file_contents = file_get_contents($this->fileSystem->realpath($uri));
      $log = Json::decode($file_contents);
      $user = User::load($log['uid']);
      $url = Url::fromRoute('fileslog.canonical', ['filename' => $file->name]);
      $message = $log['message'];
      if (strlen($message) > self::MAX_MESSAGE_LENGTH) {
        $message = substr($message, 0, self::MAX_MESSAGE_LENGTH);
        $message .= '...';
      }
      $table['#rows'][] = [
        $this->getLogLevelLabel($log['severity']),
        $log['type'],
        DrupalDateTime::createFromTimestamp($log['timestamp'])->format('Y-m-d H:i:s'),
        Markup::create('<a href="' . $url->toString() . '">' . $message . '</a>'),
        Markup::create($user instanceof UserInterface && $user->id() != '0'
          ? '<a href="' . $user->toUrl()->toString() . '">' . $user->label() . '</a>'
          : $this->t('Anonymous (not verified)')),
      ];
    }

    $this->pagerManager->createPager($total, self::ITEMS_PER_PAGE);

    return [
      '#type' => 'html_tag',
      '#tag' => 'div',
      'intro' => [
        '#markup' => $this->t('Showing :offset - :amount logs of total :total', [
          ':offset' => $offset + 1,
          ':amount' => min($offset + self::ITEMS_PER_PAGE, $total),
          ':total' => $total,
        ]),
      ],
      'form' => $this->formBuilder()->getForm(FileslogFilterForm::class),
      'table' => $table,
      'pager' => [
        '#type' => 'pager',
        '#weight' => 10,
      ],
    ];
  }

  /**
   * Returns the log's severity as a label.
   *
   * @param int $severity
   *   The log's severity.
   *
   * @return bool|mixed
   */
  protected function getLogLevelLabel(int $severity) {
    $log_levels = RfcLogLevel::getLevels();
    return $log_levels[$severity] ?? $log_levels[0] ?? FALSE;
  }

}

==> fileslog-1.0.1.tar.gz: fileslog/src/Controller/FilesLogController.php <==
<?php

namespace Drupal\fileslog\Controller;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Http\RequestStack;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\Core\Pager\PagerManagerInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\fileslog\Form\FileslogFilterForm;
use Drupal\fileslog\Logger\FilesLog;
use Drupal\user\Entity\User;
use Drupal\user\UserInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Renders the fileslog routes.
 */
class FilesLogController extends ControllerBase {

  /**
   * Define defaults.
   */
  protected const MAX_MESSAGE_LENGTH = 64;
  protected const ITEMS_PER_PAGE = 25;

  /**
   * The filesystem service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected FileSystemInterface $fileSystem;

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request|null
   */
  protected ?Request $request;

  /**
   * The pager manager.
   *
   * @var \Drupal\Core\Pager\PagerManagerInterface
   */
  protected PagerManagerInterface $pagerManager;

  /**
   * Constructs the controller.
   *
   * @param \Drupal\Core\File\FileSystemInterface $filesystem
   *   The filesystem service.
   * @param \Drupal\Core\Http\RequestStack $request_stack
   *   The request stack.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder.
   * @param \Drupal\Core\Pager\PagerManagerInterface $pager_manager
   *   The pager manager.
   */
  public function __construct(
    FileSystemInterface $filesystem,
    RequestStack $request_stack,
    FormBuilderInterface $form_builder,
    PagerManagerInterface $pager_manager
  ) {
    $this->fileSystem = $filesystem;
    $this->request = $request_stack->getCurrentRequest();
    $this->formBuilder = $form_builder;
    $this->pagerManager = $pager_manager;
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('file_system'),
      $container->get('request_stack'),
      $container->get('form_builder'),
      $container->get('pager.manager')
    );
  }

  /**
   * View page for each log.
   *
   * @param string $filename
   *   The log's filename.
   *
   * @return array
   *   The render array.
   *
   * @throws \Drupal\Core\Entity\EntityMalformedException
   */
  public function view(string $filename): array {
    $uri = FilesLog::DIRECTORY . '/' . $filename . '.json';
    $file_contents = file_get_contents($this->fileSystem->realpath($uri));
    $log = Json::decode($file_contents);
    $user = User::load($log['uid']);

    return [
      '#type' => 'inline_template',
      '#template' => '<span class="fileslog--back-to-overview"><a href="javascript:history.back();" class="button">{{ "Back to overview"|t }}</a></span>
<table>
  <tr><th><strong>{{ "Type"|t }}</strong></th><td>{{ type }}</td></tr>
  <tr><th><strong>{{ "Date"|t }}</strong></th><td>{{ date }}</td></tr>
  <tr><th><strong>{{ "User"|t }}</strong></th><td>{{ user|raw }}</td></tr>
  <tr><th><strong>{{ "Location"|t }}</strong></th><td>{{ uri }}</td></tr>
  <tr><th><strong>{{ "Referer"|t }}</strong></th><td>{{ referer }}</td></tr>
  <tr><th><strong>{{ "Severity"|t }}</strong></th><td>{{ severity }}</td></tr>
  <tr><td colspan="2"><strong>{{ "Message"|t }}:</strong><pre>{{ message }}</pre></td></tr>
</table>',
      '#context' => [
        'type' => $log['type'],
        'severity' => $this->getLogLevelLabel($log['severity']),
        'user' => $user instanceof UserInterface && $user->id() != '0'
          ? '<a href="' . $user->toUrl()->toString() . '">' . $user->label() . '</a>'
          : $this->t('Anonymous (not verified)'),
        'date' => DrupalDateTime::createFromTimestamp($log['timestamp'] ?? 0)->format('Y-m-d H:i:s'),
        'uri' => $log['request_uri'],
        'referer' => $log['referer'],
        'message' => $log['message'],
      ],
    ];
  }

  /**
   * Overview of logs.
   *
   * @return array
   *   The render array.
   *
   * @throws \Drupal\Core\Entity\EntityMalformedException
   */
  public function overview(): array {
    $table = [
      '#type' => 'table',
      '#header' => [
        '',
        $this->t('Type'),
        $this->t('Date'),
        $this->t('Message'),
        $this->t('User'),
      ],
      '#rows' => [],
    ];

    // Retrieve all .json files from the directory.
    $files = $this->fileSystem->scanDirectory(FilesLog::DIRECTORY, '/(.?)\.json/', ['recurse' => FALSE]);
    // Sort the log files in reverse, so the latest show up first.
    krsort($files);
    $filters = $this->request->getSession()->get(FileslogFilterForm::SESSION_VALUE_NAME, []);
    $levels = $filters['severity'] ?? [];
    if (count($levels) > 0) {
      $files = array_filter($files, function ($file) use ($levels) {
        foreach ($levels as $filter_level) {
          [$timestamp, $log_level] = explode('-', $file->name);
          if ($log_level == $filter_level) {
            return TRUE;
          }
        }
        return FALSE;
      });
    }

    $page = $this->pagerManager->findPage();
    $offset = $page * self::ITEMS_PER_PAGE;
    $total = count($files);

    $files = array_slice($files, $offset, self::ITEMS_PER_PAGE);
    foreach ($files as $uri => $file) {
      $file_contents = file_get_contents($this->fileSystem->realpath($uri));
      $log = Json::decode($file_contents);
      $user = User::load($log['uid']);
      $url = Url::fromRoute('fileslog.canonical', ['filename' => $file->name]);
      $message = $log['message'];
      if (strlen($message) > self::MAX_MESSAGE_LENGTH) {
        $message = substr($message, 0, self::MAX_MESSAGE_LENGTH);
        $message .= '...';
      }
      $table['#rows'][] = [
        $this->getLogLevelLabel($log['severity']),
        $log['type'],
        DrupalDateTime::createFromTimestamp($log['timestamp'])->format('Y-m-d H:i:s'),
        Markup::create('<a href="' . $url->toString() . '">' . $message . '</a>'),
        Markup::create($user instanceof UserInterface && $user->id() != '0'
          ? '<a href="' . $user->toUrl()->toString() . '">' . $user->label() . '</a>'
          : $this->t('Anonymous (not verified)')),
      ];
    }

    $this->pagerManager->createPager($total, self::ITEMS_PER_PAGE);

    return [
      '#type' => 'html_tag',
      '#tag' => 'div',
      'intro' => [
        '#markup' => $this->t('Showing :offset - :amount logs of total :total', [
          ':offset' => $offset + 1,
          ':amount' => min($offset + self::ITEMS_PER_PAGE, $total),
          ':total' => $total,
        ]),
      ],
      'form' => $this->formBuilder()->getForm(FileslogFilterForm::class),
      'table' => $table,
      'pager' => [
        '#type' => 'pager',
        '#weight' => 10,
      ],
    ];
  }

  /**
   * Returns the log's severity as a label.
   *
   * @param int $severity
   *   The log's severity.
   *
   * @return bool|mixed
   */
  protected function getLogLevelLabel(int $severity) {
    $log_levels = RfcLogLevel::getLevels();
    return $log_levels[$severity] ?? $log_levels[0] ?? FALSE;
  }

}
